@@ -33,89 +33,7 @@ class GetJson():
         self.from_email = from_email
         self.email_password = email_password
         self.to_email = to_email
-
-    def print_json(self):
-        parsed_json = json.dumps(self.capture_state(), indent=4, sort_keys=True)
-        print_json(parsed_json)
-        if "Cannot" in parsed_json:
-            click.secho("No Data To Create File", fg='red')
-        else:
-            if self.filetype:
-                self.pick_filetype(parsed_json)
-            if self.from_email != 'none' and self.email_password != 'none' and self.to_email != 'none':
-                self.send_email(parsed_json)            
-
-    def pick_filetype(self, parsed_json):
-        if self.filetype == "none":
-            pass
-        elif self.filetype == 'json':
-            self.json_file(parsed_json)
-        elif self.filetype == 'yaml':
-            self.yaml_file(parsed_json)
-        elif self.filetype == 'html':
-            self.html_file(parsed_json)
-        elif self.filetype == 'datatable':
-            datatable = "True"
-            self.html_file(parsed_json, datatable)
-        elif self.filetype == 'pdf':
-            self.pdf_file(parsed_json)
-        elif self.filetype == 'markdown':
-            self.markdown_file(parsed_json)
-        elif self.filetype == 'csv':
-            self.csv_file(parsed_json)
-        elif self.filetype == 'svg':
-            self.svg_file(parsed_json)
-    
-    def json_file(self, parsed_json):
-        with open(f'{self.hostname} {self.command}.json', 'w') as f:
-            f.write(parsed_json)
-        click.secho(f"JSON file created at { sys.path[0] }/{self.hostname} {self.command}.json", fg='green')
-
-    def yaml_file(self, parsed_json):
-        clean_yaml = yaml.dump(json.loads(parsed_json), default_flow_style=False)
-        with open(f'{self.hostname} {self.command}.yaml', 'w') as f:
-            f.write(clean_yaml)
-        click.secho(f"YAML file created at { sys.path[0] }/{self.hostname} {self.command}.yaml", fg='green')
-
-    def html_file(self, parsed_json, datatable):
-        good_json = json.loads(parsed_json)
-        build_direction = "TOP_TO_BOTTOM"
-        table_attributes = {"style" : "width:100%"}
-        html_version = convert(good_json, build_direction=build_direction, table_attributes=table_attributes)
-        if datatable == "True":
-            self.datatable_file(html_version)
-        else:                    
-            with open(f'{self.hostname} {self.command}.html', 'w') as f:
-                f.write(html_version)
-            click.secho(f"HTML file created at { sys.path[0] }/{self.hostname} {self.command}.html", fg='green') 
-
-    def datatable_file(self, html_version):
-        template_dir = Path(__file__).resolve().parent
-        env = Environment(loader=FileSystemLoader(template_dir))
-        datatable_template = env.get_template('datatable.j2')
-        datatable_output = datatable_template.render(table=html_version)
-        with open(f'{self.hostname} {self.command}.html', 'w') as f:
-            f.write(datatable_output)
-        click.secho(f"Datatable file created at { sys.path[0] }/{self.hostname} {self.command}.html", fg='green')
-
-    def pdf_file(self, parsed_json):
-        pdf = FPDF()
-        pdf.add_page()
-        pdf.set_font('Arial', size = 6)
-        pdf.cell(200, 10, txt = f"{self.hostname} {self.command}", ln = 1, align = 'C')
-        pdf.multi_cell(200, 10, txt = parsed_json)
-        pdf.output(f'{self.hostname} {self.command}.pdf')
-        click.secho(f"PDF file created at { sys.path[0] }/{self.hostname} {self.command}.pdf", fg='green')
-
-    def markdown_file(self, parsed_json):
-        df = pd.json_normalize(json.loads(parsed_json),max_level=2)
-        markdown_table = df.to_markdown(index='false')
-        with open(f'{self.hostname} {self.command}.md', 'w') as f:
-            f.write(markdown_table)
-        click.secho(f"Markdown file created at { sys.path[0] }/{self.hostname} {self.command}.md", fg='green')
-
-    def csv_file(self, parsed_json):
-        supported_templates = ['acl',
+        self.supported_templates = ['acl',
                             'arp',
                             'bgp',
                             'dot1x',
@@ -135,6 +53,7 @@ class GetJson():
                             'show cdp neighbors',
                             'show cdp neighbors detail',
                             'show environment',
+                            'show environment all',
                             'show etherchannel summary',
                             'show interfaces',
                             'show interfaces status',
@@ -163,7 +82,94 @@ class GetJson():
                             'show version',
                             'show vlan',
                             'show vrf']
-        for template in supported_templates:
+
+    def print_json(self):
+        parsed_json = json.dumps(self.capture_state(), indent=4, sort_keys=True)
+        print_json(parsed_json)
+        if "Cannot" in parsed_json:
+            click.secho("No Data To Create File", fg='red')
+        else:
+            if self.filetype:
+                self.pick_filetype(parsed_json)
+            if self.from_email != 'none' and self.email_password != 'none' and self.to_email != 'none':
+                self.send_email(parsed_json)            
+
+    def pick_filetype(self, parsed_json):
+        if self.filetype == "none":
+            pass
+        elif self.filetype == 'json':
+            self.json_file(parsed_json)
+        elif self.filetype == 'yaml':
+            self.yaml_file(parsed_json)
+        elif self.filetype == 'html':
+            self.html_file(parsed_json)
+        elif self.filetype == 'pdf':
+            self.pdf_file(parsed_json)
+        elif self.filetype == 'markdown':
+            self.markdown_file(parsed_json)
+        elif self.filetype == 'csv':
+            self.csv_file(parsed_json)
+        elif self.filetype == 'svg':
+            self.svg_file(parsed_json)
+    
+    def json_file(self, parsed_json):
+        with open(f'{self.hostname} {self.command}.json', 'w') as f:
+            f.write(parsed_json)
+        click.secho(f"JSON file created at { sys.path[0] }/{self.hostname} {self.command}.json", fg='green')
+
+    def yaml_file(self, parsed_json):
+        clean_yaml = yaml.dump(json.loads(parsed_json), default_flow_style=False)
+        with open(f'{self.hostname} {self.command}.yaml', 'w') as f:
+            f.write(clean_yaml)
+        click.secho(f"YAML file created at { sys.path[0] }/{self.hostname} {self.command}.yaml", fg='green')
+
+    def html_file(self, parsed_json):
+        for template in self.supported_templates:
+            if self.command == template:
+                template_dir = Path(__file__).resolve().parent
+                env = Environment(loader=FileSystemLoader(template_dir))
+                html_template = env.get_template(f'{self.os} html.j2')              
+                html_output = html_template.render(command = self.command, data_to_template=json.loads(parsed_json))
+                with open(f'{self.hostname} {self.command}.html', 'w') as f:
+                    f.write(html_output)
+                break          
+            else:        
+                good_json = json.loads(parsed_json)
+                build_direction = "TOP_TO_BOTTOM"
+                table_attributes = {"style" : "width:100%"}
+                html_version = convert(good_json, build_direction=build_direction, table_attributes=table_attributes)                 
+                with open(f'{self.hostname} {self.command}.html', 'w') as f:
+                    f.write(html_version)
+        click.secho(f"HTML file created at { sys.path[0] }/{self.hostname} {self.command}.html", fg='green') 
+
+    def pdf_file(self, parsed_json):
+        pdf = FPDF()
+        pdf.add_page()
+        pdf.set_font('Arial', size = 6)
+        pdf.cell(200, 10, txt = f"{self.hostname} {self.command}", ln = 1, align = 'C')
+        pdf.multi_cell(200, 10, txt = parsed_json)
+        pdf.output(f'{self.hostname} {self.command}.pdf')
+        click.secho(f"PDF file created at { sys.path[0] }/{self.hostname} {self.command}.pdf", fg='green')
+
+    def markdown_file(self, parsed_json):
+        for template in self.supported_templates:
+            if self.command == template:
+                template_dir = Path(__file__).resolve().parent
+                env = Environment(loader=FileSystemLoader(template_dir))
+                markdown_template = env.get_template(f'{self.os} md.j2')              
+                markdown_output = markdown_template.render(command = self.command, data_to_template=json.loads(parsed_json))
+                with open(f'{self.hostname} {self.command}.md', 'w') as f:
+                    f.write(markdown_output)
+                break          
+            else:
+                df = pd.json_normalize(json.loads(parsed_json),max_level=2)
+                markdown_table = df.to_markdown(index='false')
+                with open(f'{self.hostname} {self.command}.md', 'w') as f:
+                    f.write(markdown_table)
+        click.secho(f"Markdown file created at { sys.path[0] }/{self.hostname} {self.command}.md", fg='green')
+
+    def csv_file(self, parsed_json):
+        for template in self.supported_templates:
             if self.command == template:
                 template_dir = Path(__file__).resolve().parent
                 env = Environment(loader=FileSystemLoader(template_dir))
@@ -269,19 +275,19 @@ class GetJson():
                     command_output = f"Cannot Parse { self.command }"
             elif self.command == "config":
                 try:
-                    for n in track(range(n), description='Parsing Show Command'):
+                    for n in track(range(n), description='Parsing Show Config'):
                         command_output = device.learn(self.command)
                 except:
                     command_output = f"Cannot Parse { self.command }"
             elif self.command == "platform":
                 try:
-                    for n in track(range(n), description='Parsing Show Command'):
+                    for n in track(range(n), description='Parsing Show Platform'):
                         command_output = device.learn(self.command).to_dict()
                 except:
                     command_output = f"Cannot Parse { self.command }"
             else:
                 try:
-                    for n in track(range(n), description='Parsing Show Command'):
+                    for n in track(range(n), description='Parsing Learn Command'):
                         command_output = device.learn(self.command).info
                 except:
                     command_output = f"Cannot Parse { self.command }"
